@@ -4,9 +4,11 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from .downsampling import DownsamplingKernel
-from .exponential_decay import ExponentialDecayKernel
-from .linear_truncated_fidelity import LinearTruncatedFidelityKernel
+from botorch.models.kernels.downsampling import DownsamplingKernel
+from botorch.models.kernels.exponential_decay import ExponentialDecayKernel
+from botorch.models.kernels.linear_truncated_fidelity import (
+    LinearTruncatedFidelityKernel,
+)
 
 
 __all__ = [
