@@ -13,12 +13,11 @@ from __future__ import annotations
 from copy import deepcopy
 from typing import Any, List
 
+from botorch.exceptions.errors import BotorchTensorDimensionError
+from botorch.models.gpytorch import GPyTorchModel, ModelListGPyTorchModel
 from gpytorch.models import IndependentModelList
 from torch import Tensor
 
-from ..exceptions.errors import BotorchTensorDimensionError
-from .gpytorch import GPyTorchModel, ModelListGPyTorchModel
-
 
 class ModelListGP(IndependentModelList, ModelListGPyTorchModel):
     r"""A multi-output GP model with independent GPs for the outputs.
