@@ -27,6 +27,9 @@ from typing import Any, List, Optional, Tuple, Union
 
 import numpy as np
 import torch
+from botorch.models.model import Model
+from botorch.posteriors.gpytorch import GPyTorchPosterior
+from botorch.posteriors.posterior import Posterior
 from gpytorch import settings
 from gpytorch.constraints import GreaterThan, Positive
 from gpytorch.distributions.multivariate_normal import MultivariateNormal
@@ -44,10 +47,6 @@ from gpytorch.utils.cholesky import psd_safe_cholesky
 from scipy import optimize
 from torch import Tensor, float32, float64
 
-from ..posteriors.gpytorch import GPyTorchPosterior
-from ..posteriors.posterior import Posterior
-from .model import Model
-
 
 class PairwiseGP(Model, GP):
     r""" Probit GP for preference learning with Laplace approximation
@@ -445,7 +444,7 @@ class PairwiseGP(Model, GP):
             utility: A Tensor of shape `batch_size x n`
         """
         _, _, z_logcdf, _ = self._calc_z(utility, self.D, self.std_noise)
-        loss1 = -torch.sum(z_logcdf, dim=-1)
+        loss1 = -(torch.sum(z_logcdf, dim=-1))
         inv_prod = torch.cholesky_solve(utility.unsqueeze(-1), self.covar_chol)
         loss2 = 0.5 * (utility.unsqueeze(-2) @ inv_prod).squeeze(-1).squeeze(-1)
         loss = loss1 + loss2
