@@ -4,8 +4,8 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from .input import ChainedInputTransform, Normalize
-from .outcome import ChainedOutcomeTransform, Log, Standardize
+from botorch.models.transforms.input import ChainedInputTransform, Normalize
+from botorch.models.transforms.outcome import ChainedOutcomeTransform, Log, Standardize
 
 
 __all__ = [
