@@ -4,10 +4,14 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from .initializers import initialize_q_batch, initialize_q_batch_nonneg
-from .numpy_converter import module_to_array, set_params_with_array
-from .optimize import gen_batch_initial_conditions, optimize_acqf, optimize_acqf_cyclic
-from .stopping import ExpMAStoppingCriterion
+from botorch.optim.initializers import initialize_q_batch, initialize_q_batch_nonneg
+from botorch.optim.numpy_converter import module_to_array, set_params_with_array
+from botorch.optim.optimize import (
+    gen_batch_initial_conditions,
+    optimize_acqf,
+    optimize_acqf_cyclic,
+)
+from botorch.optim.stopping import ExpMAStoppingCriterion
 
 
 __all__ = [
