@@ -71,31 +71,31 @@ def optimize_acqf(
         sequential: If False, uses joint optimization, otherwise uses sequential
             optimization.
 
-        Returns:
-            A two-element tuple containing
+    Returns:
+        A two-element tuple containing
 
-           - a `(num_restarts) x q x d`-dim tensor of generated candidates.
-           - a tensor of associated acquisiton values. If `sequential=False`,
-             this is a `(num_restarts)`-dim tensor of joint acquisition values
-             (with explicit restart dimension if `return_best_only=False`). If
-             `sequential=True`, this is a `q`-dim tensor of expected acquisition
-             values conditional on having observed canidates `0,1,...,i-1`.
+        - a `(num_restarts) x q x d`-dim tensor of generated candidates.
+        - a tensor of associated acquisition values. If `sequential=False`,
+            this is a `(num_restarts)`-dim tensor of joint acquisition values
+            (with explicit restart dimension if `return_best_only=False`). If
+            `sequential=True`, this is a `q`-dim tensor of expected acquisition
+            values conditional on having observed canidates `0,1,...,i-1`.
 
-        Example:
-            >>> # generate `q=2` candidates jointly using 20 random restarts
-            >>> # and 512 raw samples
-            >>> candidates, acq_value = optimize_acqf(qEI, bounds, 2, 20, 512)
+    Example:
+        >>> # generate `q=2` candidates jointly using 20 random restarts
+        >>> # and 512 raw samples
+        >>> candidates, acq_value = optimize_acqf(qEI, bounds, 2, 20, 512)
 
-            >>> generate `q=3` candidates sequentially using 15 random restarts
-            >>> # and 256 raw samples
-            >>> qEI = qExpectedImprovement(model, best_f=0.2)
-            >>> bounds = torch.tensor([[0.], [1.]])
-            >>> candidates, acq_value_list = optimize_acqf(
-            >>>     qEI, bounds, 3, 15, 256, sequential=True
-            >>> )
+        >>> generate `q=3` candidates sequentially using 15 random restarts
+        >>> # and 256 raw samples
+        >>> qEI = qExpectedImprovement(model, best_f=0.2)
+        >>> bounds = torch.tensor([[0.], [1.]])
+        >>> candidates, acq_value_list = optimize_acqf(
+        >>>     qEI, bounds, 3, 15, 256, sequential=True
+        >>> )
 
     """
-    if sequential:
+    if sequential and q > 1:
         if not return_best_only:
             raise NotImplementedError(
                 "return_best_only=False only supported for joint optimization"
@@ -106,7 +106,7 @@ def optimize_acqf(
                 "acquisition functions. Must have `sequential=False`."
             )
         candidate_list, acq_value_list = [], []
-        candidates = torch.tensor([])
+        candidates = torch.tensor([], device=bounds.device, dtype=bounds.dtype)
         base_X_pending = acq_function.X_pending
         for i in range(q):
             candidate, acq_value = optimize_acqf(
@@ -209,7 +209,7 @@ def optimize_acqf_cyclic(
     post_processing_func: Optional[Callable[[Tensor], Tensor]] = None,
     batch_initial_conditions: Optional[Tensor] = None,
     cyclic_options: Optional[Dict[str, Union[bool, float, int, str]]] = None,
-) -> float:
+) -> Tuple[Tensor, Tensor]:
     r"""Generate a set of `q` candidates via cyclic optimization.
 
     Args:
@@ -235,23 +235,24 @@ def optimize_acqf_cyclic(
             If no initial conditions are provided, the default initialization will
             be used.
         cyclic_options: Options for stopping criterion for outer cyclic optimization.
-        Returns:
-            A two-element tuple containing
 
-           - a `q x d`-dim tensor of generated candidates.
-           - a `q`-dim tensor of expected acquisition
-             values, where the `i`th value is the acquistion value conditional on
-             having observed all candidates except candidate `i`.
+    Returns:
+        A two-element tuple containing
 
-        Example:
-            >>> # generate `q=3` candidates cyclically using 15 random restarts
-            >>> # 256 raw samples, and 4 cycles
-            >>>
-            >>> qEI = qExpectedImprovement(model, best_f=0.2)
-            >>> bounds = torch.tensor([[0.], [1.]])
-            >>> candidates, acq_value_list = optimize_acqf_cyclic(
-            >>>     qEI, bounds, 3, 15, 256, cyclic_options={"maxiter": 4}
-            >>> )
+        - a `q x d`-dim tensor of generated candidates.
+        - a `q`-dim tensor of expected acquisition values, where the value at
+            index `i` is the acquisition value conditional on having observed
+            all candidates except candidate `i`.
+
+    Example:
+        >>> # generate `q=3` candidates cyclically using 15 random restarts
+        >>> # 256 raw samples, and 4 cycles
+        >>>
+        >>> qEI = qExpectedImprovement(model, best_f=0.2)
+        >>> bounds = torch.tensor([[0.], [1.]])
+        >>> candidates, acq_value_list = optimize_acqf_cyclic(
+        >>>     qEI, bounds, 3, 15, 256, cyclic_options={"maxiter": 4}
+        >>> )
 
     """
     # for the first cycle, optimize the q candidates sequentially
@@ -306,3 +307,79 @@ def optimize_acqf_cyclic(
             stop = stopping_criterion.evaluate(fvals=acq_vals)
         acq_function.set_X_pending(base_X_pending)
     return candidates, acq_vals
+
+
+def optimize_acqf_list(
+    acq_function_list: List[AcquisitionFunction],
+    bounds: Tensor,
+    num_restarts: int,
+    raw_samples: int,
+    options: Optional[Dict[str, Union[bool, float, int, str]]] = None,
+    inequality_constraints: Optional[List[Tuple[Tensor, Tensor, float]]] = None,
+    equality_constraints: Optional[List[Tuple[Tensor, Tensor, float]]] = None,
+    fixed_features: Optional[Dict[int, float]] = None,
+    post_processing_func: Optional[Callable[[Tensor], Tensor]] = None,
+) -> Tuple[Tensor, Tensor]:
+    r"""Generate a list of candidates from a list of acquisition functions.
+
+    The acquisition functions are optimized in sequence, with previous candidates
+    set as `X_pending`. This is also known as sequential greedy optimization.
+
+    Args:
+        acq_function_list: A list of acquisition functions.
+        bounds: A `2 x d` tensor of lower and upper bounds for each column of `X`.
+        num_restarts:  Number of starting points for multistart acquisition
+            function optimization.
+        raw_samples: Number of samples for initialization
+        options: Options for candidate generation.
+        inequality constraints: A list of tuples (indices, coefficients, rhs),
+            with each tuple encoding an inequality constraint of the form
+            `\sum_i (X[indices[i]] * coefficients[i]) >= rhs`
+        equality constraints: A list of tuples (indices, coefficients, rhs),
+            with each tuple encoding an inequality constraint of the form
+            `\sum_i (X[indices[i]] * coefficients[i]) = rhs`
+        fixed_features: A map `{feature_index: value}` for features that
+            should be fixed to a particular value during generation.
+        post_processing_func: A function that post-processes an optimization
+            result appropriately (i.e., according to `round-trip`
+            transformations).
+
+    Returns:
+        A two-element tuple containing
+
+        - a `q x d`-dim tensor of generated candidates.
+        - a `q`-dim tensor of expected acquisition values, where the value at
+            index `i` is the acquisition value conditional on having observed
+            all candidates except candidate `i`.
+
+    """
+    if not acq_function_list:
+        raise ValueError("acq_function_list must be non-empty.")
+    candidate_list, acq_value_list = [], []
+    candidates = torch.tensor([], device=bounds.device, dtype=bounds.dtype)
+    base_X_pending = acq_function_list[0].X_pending
+    for acq_function in acq_function_list:
+        if candidate_list:
+            acq_function.set_X_pending(
+                torch.cat([base_X_pending, candidates], dim=-2)
+                if base_X_pending is not None
+                else candidates
+            )
+        candidate, acq_value = optimize_acqf(
+            acq_function=acq_function,
+            bounds=bounds,
+            q=1,
+            num_restarts=num_restarts,
+            raw_samples=raw_samples,
+            options=options or {},
+            inequality_constraints=inequality_constraints,
+            equality_constraints=equality_constraints,
+            fixed_features=fixed_features,
+            post_processing_func=post_processing_func,
+            return_best_only=True,
+            sequential=False,
+        )
+        candidate_list.append(candidate)
+        acq_value_list.append(acq_value)
+        candidates = torch.cat(candidate_list, dim=-2)
+    return candidates, torch.stack(acq_value_list)
