@@ -1,11 +1,15 @@
 #!/usr/bin/env python3
-
-# Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved
+# Copyright (c) Facebook, Inc. and its affiliates.
+#
+# This source code is licensed under the MIT license found in the
+# LICENSE file in the root directory of this source tree.
 
 r"""
 Helpers for handling objectives.
 """
 
+from __future__ import annotations
+
 from typing import Callable, List, Optional
 
 import torch
@@ -13,7 +17,7 @@ from torch import Tensor
 
 
 def get_objective_weights_transform(
-    weights: Optional[Tensor]
+    weights: Optional[Tensor],
 ) -> Callable[[Tensor], Tensor]:
     r"""Create a linear objective callable from a set of weights.
 
