@@ -15,13 +15,12 @@ from contextlib import contextmanager
 from typing import Generator, Optional
 
 import torch
+from botorch.exceptions.warnings import SamplingWarning
+from botorch.posteriors.posterior import Posterior
+from botorch.sampling.qmc import NormalQMCEngine
 from torch import LongTensor, Tensor
 from torch.quasirandom import SobolEngine
 
-from ..exceptions.warnings import SamplingWarning
-from ..posteriors.posterior import Posterior
-from ..sampling.qmc import NormalQMCEngine
-
 
 @contextmanager
 def manual_seed(seed: Optional[int] = None) -> Generator[None, None, None]:
